cih = {
    "ecom_inter": "PAIEMENT INTERNET INTERNATIONAL",
    "ecom_national": "PAIEMENT INTERNET NATIONAL",
    "wire_in_same_bank": "VIREMENT RECU DE",
    "wire_in_conf": "VIRT RECU",
    "wire_out": "VIREMENT EMIS EN FAVEUR DE",
    "withdrawal_gab": "RETRAIT CARTE",
    "invoice_pay": " PAIEMENT FACTURE",
    "card_pay": "PAIEMENT PAR CARTE",
    "wire_fee": "COMMISSION VIREMENT EMIS",
    "refund_card": "REGLEMENT CREDIT CARTE",
    "ext_gab_fee": "FRAIS RETRAIT GAB CONFRERE",
    "allow_ecom_fee": "FRAIS ANNUELS DOTATIONS"
}

awb = {
    "wire_in_same_bank": "VIR.WEB RECU DE",
    "wire_in_conf": "VIREMENT RECU DE",
    "wire_out": "VIR WEB VERS",
    "withdrawal_gab": "AWBGAB",
    "invoice_pay": "PAIEMENT ",
    "card_pay": "PAIMENT/CB",
    "ext_gab_fee": "FRAIS/RETRAIT ESP GAB",
    "ecom_national": "",
    "ecom_inter": "",
    "card_pay": ""
}

banks = {
    'CIH': cih,
    'AWB': awb
}
